@@ -329,12 +329,7 @@ class GeoArray(object):
     @projection.setter
     def projection(self, prj):
         # type: (str) -> None
-        if self.filePath and self.projection:
-            assert self.projection is None or prj_equal(self.projection, prj), \
-                "Cannot set %s.projection to the given value because it does not match the projection from the file " \
-                "on disk." % self.__class__.__name__
-        else:
-            self._projection = prj
+        self._projection = prj
 
     prj = alias_property('projection')
 
